aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/mcp/mcp_forum.php
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/includes/mcp/mcp_forum.php')
-rw-r--r--phpBB/includes/mcp/mcp_forum.php6
1 files changed, 5 insertions, 1 deletions
diff --git a/phpBB/includes/mcp/mcp_forum.php b/phpBB/includes/mcp/mcp_forum.php
index f73973b81d..c2e17e9f39 100644
--- a/phpBB/includes/mcp/mcp_forum.php
+++ b/phpBB/includes/mcp/mcp_forum.php
@@ -334,16 +334,20 @@ function mcp_forum_view($id, $mode, $action, $forum_info)
));
}
+ $row_ary = $row;
/**
* Modify the topic data before it is assigned to the template in MCP
*
* @event core.mcp_view_forum_modify_topicrow
* @var array row Array with topic data
* @var array topic_row Template array with topic data
* @since 3.1.0-a1
+ * @change 3.2.0-a1 Replace row with row_ary
*/
$vars = array('row', 'topic_row');
extract($phpbb_dispatcher->trigger_event('core.mcp_view_forum_modify_topicrow', compact($vars)));
+ $row = $row_ary;
+ unset($row_ary);
$template->assign_block_vars('topicrow', $topic_row);
}
@@ -334,16 +334,20 @@ function mcp_forum_view($id, $mode, $action, $forum_info)
*
* @event core.mcp_view_forum_modify_topicrow
- * @var array row Array with topic data
+ * @var array row_ary Array with topic data
* @var array topic_row Template array with topic data
* @since 3.1.0-a1